@@ -10,7 +10,6 @@ from mipdb.database import DataBase, Connection
 from mipdb.database import METADATA_SCHEMA
 from mipdb.database import METADATA_TABLE
 from mipdb.dataelements import CommonDataElement
-from mipdb.exceptions import UserInputError
 from mipdb.schema import Schema
 
 
@@ -251,15 +250,11 @@ class PrimaryDataTable(Table):
     def from_cdes(
         cls, schema: Schema, cdes: List[CommonDataElement]
     ) -> "PrimaryDataTable":
-        columns = []
-        for cde in cdes:
-            if '"' in cde.code:
-                raise UserInputError(f'CDE code: {cde.code} contains prohibited character double quotes (")')
-            columns.append(sql.Column(cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]], quote=True))
+        columns = [sql.Column(cde.code, STR2SQLTYPE[json.loads(cde.metadata)["sql_type"]], quote=True) for cde in cdes]
         columns.insert(
             0,
             sql.Column(
-                "row_id", SQLTYPES.INTEGER, primary_key=True, autoincrement=True
+                "row_id", SQLTYPES.INTEGER, primary_key=True, autoincrement=True, quote=True
             ),
         )
         table = sql.Table(
